@@ -10,14 +10,11 @@ import requests
 from decouple import config
 
 from .. import GetChromeDriver
-from .. import constants
 from .. import __version__
-from ..platforms import Platforms
+from .. import constants
 
 name = 'get-chrome-driver'
 
-platforms = Platforms()
-
 stable_version = config('STABLE_VERSION')
 random_version = config('RANDOM_VERSION')
 
@@ -42,44 +39,20 @@ os.chdir(os.path.dirname(__file__))
 
 
 class TestApp:
-
-    ###################################
-    # LI TEXT "LATEST STABLE VERSION" #
-    ###################################
     def test_text_match_latest_stable(self):
         match_found = False
 
-        result = requests.get(constants.CHROMEDRIVER_CHROMIUM_URL)
+        result = requests.get(constants.url_chromium)
         soup = BeautifulSoup(result.content, 'html.parser')
-        ul = soup.select_one(constants.CSS_VERSIONS_SELECTOR_UL)
+        ul = soup.select_one(constants.css_selector_versions)
         for li in ul:
             text = li.text.replace(u'\u00A0', ' ')
-            if text[:len(constants.LATEST_STABLE_VERSION_STR)].lower() == constants.LATEST_STABLE_VERSION_STR.lower():
+            if text[:len(constants.latest_stable_version_str)].lower() == constants.latest_stable_version_str.lower():
                 match_found = True
                 break
 
         assert match_found is True
 
-    #################################
-    # LI TEXT "LATEST BETA VERSION" #
-    #################################
-    def test_text_match_latest_beta(self):
-        match_found = False
-
-        result = requests.get(constants.CHROMEDRIVER_CHROMIUM_URL)
-        soup = BeautifulSoup(result.content, 'html.parser')
-        ul = soup.select_one(constants.CSS_VERSIONS_SELECTOR_UL)
-        for li in ul:
-            text = li.text.replace(u'\u00A0', ' ')
-            if text[:len(constants.LATEST_BETA_VERSION_STR)].lower() == constants.LATEST_BETA_VERSION_STR.lower():
-                match_found = True
-                break
-
-        assert match_found is True
-
-    ##################
-    # STABLE VERSION #
-    ##################
     def test_stable_version(self):
         out = subprocess.run(args=[name, '--stable-version'],
                              universal_newlines=True,
@@ -87,9 +60,6 @@ class TestApp:
         actual = out.stdout.split()[0]
         assert stable_version == str(actual)
 
-    ######################
-    # RANDOM VERSION URL #
-    ######################
     def test_random_version_url(self):
         url = random_version_url
         out = subprocess.run(args=[name, '--version-url', random_version],
@@ -98,9 +68,6 @@ class TestApp:
         actual = out.stdout.split()[0]
         assert url, str(actual)
 
-    ######################
-    # STABLE VERSION URL #
-    ######################
     def test_stable_version_url(self):
         url = stable_version_url
         out = subprocess.run(args=[name, '--stable-url'],
@@ -109,94 +76,67 @@ class TestApp:
         actual = out.stdout.split()[0]
         assert url == str(actual)
 
-    ##############################
-    # AUTO DOWNLOAD - NO EXTRACT #
-    ##############################
     def test_auto_download_no_extract(self):
         get_driver = GetChromeDriver()
         version = get_driver.matching_version()
         subprocess.run(args=[name, '--auto-download'], stdout=subprocess.PIPE)
-        file_path = get_driver._default_output_path(version) + '/' + file_name_zipped
+        file_path = get_driver._output_path(version) + '/' + file_name_zipped
         result = path.exists(file_path)
         assert result
 
-    ###########################
-    # AUTO DOWNLOAD - EXTRACT #
-    ###########################
     def test_auto_download_extract(self):
         get_driver = GetChromeDriver()
         version = get_driver.matching_version()
         subprocess.run(args=[name, '--auto-download', '--extract'], stdout=subprocess.PIPE)
-        file_path_extracted = get_driver._default_output_path(version) + '/' + file_name
+        file_path_extracted = get_driver._output_path(version) + '/' + file_name
         result = path.exists(file_path_extracted)
         assert result
 
-    ################################################
-    # AUTO DOWNLOAD - EXTRACT AND WITH CUSTOM PATH #
-    ################################################
     def test_auto_download_extract_custom_path(self):
         get_driver = GetChromeDriver()
         get_driver.auto_download(output_path='webdriver/bin/chromedriver', extract=True)
         result = path.exists('webdriver/bin/chromedriver/' + file_name)
         assert result
 
-    ########################################
-    # DOWNLOAD STABLE VERSION - NO EXTRACT #
-    ########################################
     def test_download_stable_version_no_extract(self):
         get_driver = GetChromeDriver()
         version = stable_version
         subprocess.run(args=[name, '--download-stable'], stdout=subprocess.PIPE)
-        file_path = get_driver._default_output_path(version) + '/' + file_name_zipped
+        file_path = get_driver._output_path(version) + '/' + file_name_zipped
         result = path.exists(file_path)
         assert result
 
-    #####################################
-    # DOWNLOAD STABLE VERSION - EXTRACT #
-    #####################################
     def test_download_stable_version_extract(self):
         get_driver = GetChromeDriver()
         version = stable_version
         subprocess.run(args=[name, '--download-stable', '--extract'], stdout=subprocess.PIPE)
-        file_path_extracted = get_driver._default_output_path(version) + '/' + file_name
+        file_path_extracted = get_driver._output_path(version) + '/' + file_name
         result = path.exists(file_path_extracted)
         assert result
 
-    ##########################################################
-    # STABLE VERSION DOWNLOAD - EXTRACT AND WITH CUSTOM PATH #
-    ##########################################################
     def test_download_stable_version_extract_custom_path(self):
         get_driver = GetChromeDriver()
         get_driver.download_stable_version(output_path='webdriver/bin/chromedriver', extract=True)
         result = path.exists('webdriver/bin/chromedriver/' + file_name)
         assert result
 
-    ########################################
-    # DOWNLOAD RANDOM VERSION - NO EXTRACT #
-    ########################################
     def test_download_random_version_no_extract(self):
         get_driver = GetChromeDriver()
         version = random_version
         subprocess.run(args=[name, '--download-version', version], stdout=subprocess.PIPE)
-        file_path = get_driver._default_output_path(version) + '/' + file_name_zipped
+        file_path = get_driver._output_path(version) + '/' + file_name_zipped
         result = path.exists(file_path)
         assert result
 
-    #####################################
-    # DOWNLOAD RANDOM VERSION - EXTRACT #
-    #####################################
     def test_download_random_version_extract(self):
         get_driver = GetChromeDriver()
         version = random_version
         subprocess.run(args=[name, '--download-version', version, '--extract'],
                        stdout=subprocess.PIPE)
-        file_path_extracted = get_driver._default_output_path(version) + '/' + file_name
+        file_path_extracted = get_driver._output_path(version) + '/' + file_name
         result = path.exists(file_path_extracted)
         assert result
 
-    ##########################################################
-    # RANDOM VERSION DOWNLOAD - EXTRACT AND WITH CUSTOM PATH #
-    ##########################################################
     def test_download_random_version_extract_custom_path(self):
         get_driver = GetChromeDriver()
         version = random_version
@@ -204,9 +144,6 @@ class TestApp:
         result = path.exists('webdriver/bin/chromedriver/' + file_name)
         assert result
 
-    ###########
-    # VERSION #
-    ###########
     def test_version(self):
         out = subprocess.run(args=[name, '--version'],
                              universal_newlines=True,
@@ -214,17 +151,14 @@ class TestApp:
         actual = out.stdout.split()[0]
         assert 'v' + __version__ == str(actual)
 
-    ###########
-    # CLEANUP #
-    ###########
     @pytest.fixture(scope='function', autouse=True)
     def cleanup(self):
         yield
         try:
-            shutil.rmtree(constants.CHROMEDRIVER)
+            shutil.rmtree('webdriver')
         except (FileNotFoundError, PermissionError):
             pass
         try:
-            shutil.rmtree(constants.WEBDRIVER)
+            shutil.rmtree('chromedriver')
         except (FileNotFoundError, PermissionError):
             pass
